
# Slot: generation_date


date and time that the schema was loaded/generated

URI: [linkml:generation_date](https://w3id.org/linkml/generation_date)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..1</sub> [Datetime](Datetime.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | owl |

